@@ -28,7 +28,7 @@ const SIGINT = 2;
 const SIGTERM = 15;
 
 let application = null;
-
+let settings = null;
 
 const Application = new Lang.Class({
     Name: 'Application',
@@ -81,7 +81,8 @@ const Application = new Lang.Class({
         Gst.init(null, 0);
         this._initAppMenu();
         application = this;
-
+        
+        settings = new Gio.Settings({ schema: 'org.gnome.gnome-sound-recorder' });
         /* Translators: "Recordings" here refers to the name of the directory where the application places files */
         let path = GLib.build_filenamev([GLib.get_home_dir(), _("Recordings")]);
 
@@ -114,6 +115,33 @@ const Application = new Lang.Class({
             }));
     },
     
+    getPreferences: function() {
+        let set = settings.get_int("media-type-preset");
+        return set;
+     },
+    
+    setPreferences: function(profileName) {
+        settings.set_int("media-type-preset", profileName);
+    },
+     
+    getMicVolume: function() {
+        let micVolLevel = settings.get_double("mic-volume");
+        return micVolLevel;
+    },
+     
+    setMicVolume: function(level) {
+         settings.set_double("mic-volume", level);
+    },
+    
+    getSpeakerVolume: function() {
+        let speakerVolLevel = settings.get_double("speaker-volume");
+        return speakerVolLevel;
+    },
+     
+    setSpeakerVolume: function(level) {
+         settings.set_double("speaker-volume", level);
+    },
+    
     _showAbout: function() {
         let aboutDialog = new Gtk.AboutDialog({ use_header_bar: true });
         aboutDialog.artists = [ 'Reda Lazri <the.red.shortcut@gmail.com>',
@@ -127,7 +155,7 @@ const Application = new Lang.Class({
         aboutDialog.copyright = 'Copyright ' + String.fromCharCode(0x00A9) + ' 2013' + String.fromCharCode(0x2013) + 'Meg Ford';
         aboutDialog.license_type = Gtk.License.GPL_2_0;
         aboutDialog.logo_icon_name = 'audio-input-microphone';
-        aboutDialog.version = '3.12.1';
+        aboutDialog.version = '3.12.2';
         aboutDialog.website = 'http://live.gnome.org/GnomeSoundRecorder';
         aboutDialog.wrap_license = true;
         aboutDialog.modal = true;
