@@ -95,9 +95,7 @@ const Record = new Lang.Class({
                             this.taglist = Gst.TagList.new_empty();
                             this.taglist.add_value(Gst.TagMergeMode.APPEND, Gst.TAG_APPLICATION_NAME, _("Sound Recorder"));
                             element.merge_tags(this.taglist, Gst.TagMergeMode.REPLACE);
-                            let trackNumber = Listview.trackNumber + 1;
-                            let trackNumberString = trackNumber.toString();
-                            this.taglist.add_value(Gst.TagMergeMode.APPEND, Gst.TAG_TITLE, trackNumberString);
+                            this.taglist.add_value(Gst.TagMergeMode.APPEND, Gst.TAG_TITLE, this.initialFileName);
                             element.merge_tags(this.taglist, Gst.TagMergeMode.REPLACE);
                             this.taglist.add_value(Gst.TagMergeMode.APPEND, Gst.TAG_DATE_TIME, this.gstreamerDateTime);
                             element.merge_tags(this.taglist, Gst.TagMergeMode.REPLACE);
@@ -107,11 +105,11 @@ const Record = new Lang.Class({
         let ebinProfile = this.ebin.set_property("profile", this._mediaProfile);
         this.pipeline.add(this.ebin);
         let srcpad = this.ebin.get_static_pad("src");
-        this.giosink = Gst.ElementFactory.make("giosink", "giosink");
-        this.giosink.set_property("file", this.initialFileName);
-        this.pipeline.add(this.giosink);
+        this.filesink = Gst.ElementFactory.make("filesink", "filesink");
+        this.filesink.set_property("location", this.initialFileName);
+        this.pipeline.add(this.filesink);
         
-        if (!this.pipeline || !this.giosink) {
+        if (!this.pipeline || !this.filesink) {
             this._showErrorDialog(_('Not all elements could be created.'));
             this.onEndOfStream();
         }
@@ -119,7 +117,7 @@ const Record = new Lang.Class({
         let srcLink = this.srcElement.link(this.level);
         let levelLink = this.level.link(this.volume);
         let volLink = this.volume.link(this.ebin);
-        let ebinLink = this.ebin.link(this.giosink);
+        let ebinLink = this.ebin.link(this.filesink);
         
         if (!srcLink || !levelLink || !ebinLink) {
             this._showErrorDialog(_('Not all of the elements were linked'));
@@ -157,7 +155,7 @@ const Record = new Lang.Class({
         
         if (ret == Gst.StateChangeReturn.FAILURE) {
             this._showErrorDialog(_('Unable to set the pipeline \n to the recording state')); 
-            this.initialFileName.delete_async(GLib.PRIORITY_DEFAULT, null, null);
+            this._buildFileName.getTitle().delete_async(GLib.PRIORITY_DEFAULT, null, null);
         } else {        
             MainWindow.view.setVolume(); 
         }
@@ -289,18 +287,18 @@ const BuildFileName = new Lang.Class({
         let fileExtensionName = MainWindow.audioProfile.fileExtensionReturner();
         let dir = Gio.Application.get_default().saveDir;
         this.dateTime = GLib.DateTime.new_now_local();
-        this.clipNumber = Listview.trackNumber + 1;
+        this.clipNumber = Listview.allFilesInfo.length + 1;
         this.clipNumberString = this.clipNumber.toString();
         /* Translators: ""Clip %d"" is the default name assigned to a file created
             by the application (for example, "Clip 1"). */
         let clipName = _("Clip %d").format(this.clipNumberString);
-        let file = dir.get_child_for_display_name(clipName);
-
+        this.clip = dir.get_child_for_display_name(clipName);
+        let file = this.clip.get_path();
         return file;
     },
     
     getTitle: function() {
-        return this.title;
+        return this.clip;
     },
     
     getOrigin: function() {
